@@ -109,7 +109,7 @@ export class Test implements LimeWebComponent {
                     outlined={true}
                     icon="scrive"
                     onClick={() =>
-                        this.goToScrive(this.context.id, this.document.scrive_document_id)
+                        this.goToScrive(this.context.id, this.document?.scrive_document_id)
                     }
                 />
                 <p>
